==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebFormDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataEventArgsDescriptionMetadata } from "./WebFormDataEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebFormDescription } from "./WebFormDescription";
/**
 * @hidden
 */
var WebFormDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFormDescriptionMetadata, _super);
    function WebFormDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFormDescriptionMetadata.b = function (a) {
        if (WebFormDescriptionMetadata.a == null) {
            WebFormDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFormDescriptionMetadata.c(WebFormDescriptionMetadata.a);
        }
        if (a.j(WebFormDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFormDescriptionMetadata.a);
        WebFormDataEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebFormDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Form");
        a.item("__tagNameWC", "String:igc-form");
        a.item("Novalidate", "Boolean");
        a.item("SubmitRef", "EventRef::submit");
        a.item("ResetRef", "EventRef::reset");
    };
    WebFormDescriptionMetadata.d = function (a) {
        WebFormDescriptionMetadata.b(a);
        a.aa("WebForm", function () { return new WebFormDescription(); });
        a.z("WebForm", WebFormDescriptionMetadata.a);
    };
    WebFormDescriptionMetadata.$t = markType(WebFormDescriptionMetadata, 'WebFormDescriptionMetadata');
    WebFormDescriptionMetadata.a = null;
    return WebFormDescriptionMetadata;
}(Base));
export { WebFormDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebFormDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataEventArgsDescriptionMetadata } from "./WebFormDataEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebFormDescription } from "./WebFormDescription";
/**
 * @hidden
 */
var WebFormDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFormDescriptionMetadata, _super);
    function WebFormDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFormDescriptionMetadata.b = function (a) {
        if (WebFormDescriptionMetadata.a == null) {
            WebFormDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFormDescriptionMetadata.c(WebFormDescriptionMetadata.a);
        }
        if (a.k(WebFormDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFormDescriptionMetadata.a);
        WebFormDataEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebFormDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Form");
        a.item("__tagNameWC", "String:igc-form");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Novalidate", "Boolean");
        a.item("SubmitRef", "EventRef::submit");
        a.item("ResetRef", "EventRef::reset");
    };
    WebFormDescriptionMetadata.d = function (a) {
        WebFormDescriptionMetadata.b(a);
        a.ac("WebForm", function () { return new WebFormDescription(); });
        a.ab("WebForm", WebFormDescriptionMetadata.a);
    };
    WebFormDescriptionMetadata.$t = markType(WebFormDescriptionMetadata, 'WebFormDescriptionMetadata');
    WebFormDescriptionMetadata.a = null;
    return WebFormDescriptionMetadata;
}(Base));
export { WebFormDescriptionMetadata };
